AFQ-Insight: Statistical learning for tractometry data
======================================================

AFQ-Insight is a Python library for statistical learning of tractometry data.

Tractometry assesses the tissue properties of the major white matter connections
between different brain regions. AFQ-Insight inter-operates with the results of
tractometry produced by the `pyAFQ <https://yeatmanlab.github.io/pyAFQ>`_
software library. However, you can also use the output of other tractometry
pipelines if you convert them into the format produced by pyAFQ.


.. toctree::
   :maxdepth: 3
   :hidden:

   install
   user_guide
   auto_examples/index
   getting_help
   api
   contributing
   AFQ-Insight on GitHub <https://github.com/richford/AFQ-Insight>

`Getting started <quick_start.html>`_
-------------------------------------

See the `getting started <quick_start.html>`_ page for installation and basic usage instructions.

`User Guide <user_guide.html>`_
-------------------------------

See the `user guide <user_guide.html>`_ for further information on how to use *AFQ-Insight*.

`API Documentation <api.html>`_
-------------------------------

See the `API Documentation <api.html>`_ for detailed documentation of the API.

`Examples <auto_examples/index.html>`_
--------------------------------------

And look at the `example gallery <auto_examples/index.html>`_ for a set of introductory examples.

Citing *AFQ-Insight*
--------------------

If you use *AFQ-Insight* in a scientific publication, we would appreciate
citations. Please see our `citation instructions
<https://github.com/richford/AFQ-Insight#citing-AFQ-Insight>`_ for the latest
reference and a bibtex entry.

Acknowledgements
----------------

*AFQ-Insight* development was supported through a grant from the `Gordon and Betty
Moore Foundation <https://www.moore.org/>`_ and from the `Alfred P. Sloan
Foundation <https://sloan.org/>`_ to the
`University of Washington eScience Institute <http://escience.washington.edu/>`_,
NIH Collaborative Research in Computational Neuroscience grant R01EB027585-01
through the National Institute of Biomedical Imaging and Bioengineering to
Eleftherios Garyfallidis (Indiana University) and Ariel Rokem (University of
Washington) and NIH grant RF1MH121868 (PIs: Ariel Rokem, Jason Yeatman and Noah
Simon) from the National Institute of Mental Health and the BRAIN Initiative Informatics program.
